##############################################################################
#
# Copyright (c) 2007 Zope Foundation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Address Book Interfaces

$Id: interfaces.py 76933 2007-06-22 02:20:21Z srichter $
"""
__docformat__ = "reStructuredText"
import zope.interface
import zope.schema
from zope.schema import vocabulary

AddressNamesVocabulary = vocabulary.SimpleVocabulary((
    vocabulary.SimpleTerm('home', title='Home'),
    vocabulary.SimpleTerm('work', title='Work'),
    vocabulary.SimpleTerm('other', title='Other')
    ))

class IAddress(zope.interface.Interface):
    """An address."""

    street = zope.schema.TextLine(
        title='Street',
        description='Street name and number.')

    city = zope.schema.TextLine(
        title='City',
        description='City.')

    state = zope.schema.TextLine(
        title='State',
        description='State or Province.')

    zip = zope.schema.TextLine(
        title='ZIP',
        description='ZIP Code.')


class IEMail(zope.interface.Interface):
    """An E-mail address."""

    user = zope.schema.TextLine(
        title='User')

    host = zope.schema.TextLine(
        title='Host')

    fullAddress = zope.schema.TextLine(
        title='E-mail Address',
        description='The full E-mail address.')


class IPhone(zope.interface.Interface):
    """A phone number."""

    countryCode = zope.schema.TextLine(
        title='Country Code',
        default='1')

    areaCode = zope.schema.TextLine(
        title='Area Code')

    number = zope.schema.TextLine(
        title='Number')

    extension = zope.schema.TextLine(
        title='Extension',
        required=False)


class IContact(zope.interface.Interface):
    """A contact in the address book."""

    firstName = zope.schema.TextLine(
        title='First Name',
        description='First name of the person.')

    lastName = zope.schema.TextLine(
        title='Last Name',
        description='Last name of the person.')

    birthday = zope.schema.Date(
        title='Birthday',
        description='Birthday of the person.',
        required=False)

    addresses = zope.schema.Dict(
        title='Addresses',
        description='A mapping of addresses',
        key_type=zope.schema.Choice(
            __name__='addressName',
            vocabulary=AddressNamesVocabulary),
        value_type=zope.schema.Object(schema=IAddress))

    emails = zope.schema.List(
        title='E-mails',
        description='E-mails of the person.',
        value_type=zope.schema.Object(schema=IEMail))

    homePhone = zope.schema.Object(
        title='Home Phone',
        description='Home Phone Number.',
        schema=IPhone)

    cellPhone = zope.schema.Object(
        title='Cell Phone',
        description='Cell Phone Number.',
        schema=IPhone,
        required=False)

    workPhone = zope.schema.Object(
        title='Work Phone',
        description='Work Phone Number.',
        schema=IPhone,
        required=False)
