##############################################################################
#
# Copyright (c) 2007 Zope Foundation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Widgets Demo Interfaces

$Id: interfaces.py 79470 2007-09-04 22:34:23Z srichter $
"""
__docformat__ = "reStructuredText"
import datetime
import decimal
import zope.interface
import zope.schema
from zope.schema import vocabulary

vocab = vocabulary.SimpleVocabulary([
    vocabulary.SimpleVocabulary.createTerm(1, '1', 'One'),
    vocabulary.SimpleVocabulary.createTerm(2, '2', 'Two'),
    vocabulary.SimpleVocabulary.createTerm(3, '3', 'Three'),
    vocabulary.SimpleVocabulary.createTerm(4, '4', 'Four'),
    vocabulary.SimpleVocabulary.createTerm(5, '5', 'Five')
    ])

class IObjectSchema(zope.interface.Interface):

    field1 = zope.schema.TextLine(
        title='Field 1')

    field2 = zope.schema.Int(
        title='Field 2')


class IAllFields(zope.interface.Interface):
    """An interface containing all possible fields."""

    asciiField = zope.schema.ASCII(
        title='ASCII',
        description='This is an ASCII field.',
        default='This is\n ASCII.')

    asciiLineField = zope.schema.ASCIILine(
        title='ASCII Line',
        description='This is an ASCII-Line field.',
        default='An ASCII line.')

    boolField = zope.schema.Bool(
        title='Boolean',
        description='This is a Bool field.',
        default=True)

    checkboxBoolField = zope.schema.Bool(
        title='Boolean (Checkbox)',
        description='This is a Bool field displayed suing a checkbox.',
        default=True)

    bytesField = zope.schema.Bytes(
        title='Bytes',
        description='This is a Bytes field.',
        default='\10\45\n\32',
        required=False)

    bytesLineField = zope.schema.BytesLine(
        title='Bytes Line',
        description='This is a bytes line field.',
        default='A Bytes line.')

    choiceField = zope.schema.Choice(
        title='Choice',
        description='This is a choice field.',
        default=3,
        vocabulary=vocab)

    optionalChoiceField = zope.schema.Choice(
        title='Choice (Not Required)',
        description='This is a non-required choice field.',
        vocabulary=vocab,
        required=False)

    promptChoiceField = zope.schema.Choice(
        title='Choice (Explicit Prompt)',
        description='This is a choice field with an explicit prompt.',
        vocabulary=vocab,
        required=False)

    dateField = zope.schema.Date(
        title='Date',
        description='This is a Date field.',
        default=datetime.date(2007, 4, 1))

    datetimeField = zope.schema.Datetime(
        title='Date/Time',
        description='This is a Datetime field.',
        default=datetime.datetime(2007, 4, 1, 12))

    decimalField = zope.schema.Decimal(
        title='Decimal',
        description='This is a Decimal field.',
        default=decimal.Decimal('12.87'))

    dictField = zope.schema.Dict(
        title='Dictionary',
        description='This is a Dictionary field.',
        key_type=zope.schema.TextLine(),
        value_type=choiceField,
        default={'a': 1, 'c': 3})

    dottedNameField = zope.schema.DottedName(
        title='Dotted Name',
        description='This is a DottedName field.',
        default='z3c.form')

    floatField = zope.schema.Float(
        title='Float',
        description='This is a Float field.',
        default=12.8)

    frozenSetField = zope.schema.FrozenSet(
        title='Frozen Set',
        description='This is a FrozenSet field.',
        value_type=choiceField,
        default=frozenset([1, 3]) )

    idField = zope.schema.Id(
        title='Id',
        description='This is a Id field.',
        default='z3c.form')

    intField = zope.schema.Int(
        title='Integer',
        description='This is a Int field.',
        default=12345)

    listField = zope.schema.List(
        title='List',
        description='This is a List field.',
        value_type=choiceField,
        default=[1, 3])

    objectField = zope.schema.Object(
        title='Object',
        description='This is an Object field.',
        schema=IObjectSchema)

    passwordField = zope.schema.Password(
        title='Password',
        description='This is a Password field.',
        default='mypwd',
        required=False)

    setField = zope.schema.Set(
        title='Set',
        description='This is a Set field.',
        value_type=choiceField,
        default=set([1, 3]) )

    sourceTextField = zope.schema.SourceText(
        title='Source Text',
        description='This is a SourceText field.',
        default='<source />')

    textField = zope.schema.Text(
        title='Text',
        description='This is a Text field.',
        default='Some\n Text.')

    textLineField = zope.schema.TextLine(
        title='Text Line',
        description='This is a TextLine field.',
        default='Some Text line.')

    timeField = zope.schema.Time(
        title='Time',
        description='This is a Time field.',
        default=datetime.time(12, 0))

    timedeltaField = zope.schema.Timedelta(
        title='Time Delta',
        description='This is a Timedelta field.',
        default=datetime.timedelta(days=3))

    tupleField = zope.schema.Tuple(
        title='Tuple',
        description='This is a Tuple field.',
        value_type=choiceField,
        default=(1, 3))

    uriField = zope.schema.URI(
        title='URI',
        description='This is a URI field.',
        default='http://zope.org')

    hiddenField = zope.schema.TextLine(
        title='Hidden Text Line',
        description='This is a hidden TextLine field.',
        default='Some Hidden Text.')
