##############################################################################
#
# Copyright (c) 2007 Zope Foundation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Person Interfaces

$Id: interfaces.py 82177 2007-12-07 14:37:56Z ccomb $
"""
__docformat__ = "reStructuredText"
import zope.interface
import zope.schema
from z3c.form import interfaces


# ----[ Wizard Interfaces ]---------------------------------------------------

class ISaveButton(interfaces.IButton):
    """A button that causes the step data to be saved."""

class IBackButton(interfaces.IButton):
    """A button that returns to some previous state or screen."""

class IForwardButton(interfaces.IButton):
    """A button that returns to some next state or screen."""

class IStep(zope.interface.Interface):
    """An interface marking a step sub-form."""

    def isComplete():
        """Determines whether a step is complete."""

class IWizard(zope.interface.Interface):
    """An interface marking the controlling wizard form."""

    def isComplete():
        """Determines whether the wizard is complete."""

    def getCurrentStep():
        """Return the current step as an instance."""

    def isFirstStep():
        """Determine whether the current step is the first one."""

    def isLastStep():
        """Determine whether the current step is the last one."""


# ----[ Content Interfaces ]--------------------------------------------------

class IAddress(zope.interface.Interface):

    street = zope.schema.TextLine(
        title='Street',
        description='The street address.',
        default='',
        missing_value='',
        required=True)

    zip = zope.schema.TextLine(
        title='Zip',
        description='The zip code of the location.',
        default='',
        missing_value='',
        required=True)

    city = zope.schema.TextLine(
        title='City',
        description='The city.',
        default='',
        missing_value='',
        required=True)


class IPersonalInfo(IAddress):

    lastName = zope.schema.TextLine(
        title='Last Name',
        description='The last name of the person.',
        default='',
        missing_value='',
        required=True)

    firstName = zope.schema.TextLine(
        title='First Name',
        description='The first name of the person.',
        default='',
        missing_value='',
        required=True)

    phone = zope.schema.TextLine(
        title='Phone',
        description='The phone number.',
        default='',
        missing_value='',
        required=False)

    email = zope.schema.TextLine(
        title='Email',
        description='The email address.',
        required=False)


class IEmployerInfo(IAddress):

    name = zope.schema.TextLine(
        title='Name',
        description='The name of the employer.',
        default='',
        missing_value='',
        required=True)


class IPerson(IPersonalInfo):

    father = zope.schema.Object(
        title='Father',
        description="Father's personal info.",
        schema=IPersonalInfo,
        required=True)

    mother = zope.schema.Object(
        title='Mother',
        description="Mother's personal info.",
        schema=IPersonalInfo,
        required=True)

    employer = zope.schema.Object(
        title='Employer',
        description="Employer's info.",
        schema=IEmployerInfo,
        required=True)
